# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sdk/stream/aggregates_ohlcv_v1/request.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from kaikosdk.core import instrument_criteria_pb2 as sdk_dot_core_dot_instrument__criteria__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,sdk/stream/aggregates_ohlcv_v1/request.proto\x12\x08kaikosdk\x1a\"sdk/core/instrument_criteria.proto\"n\n\x1eStreamAggregatesOHLCVRequestV1\x12\x39\n\x13instrument_criteria\x18\x01 \x01(\x0b\x32\x1c.kaikosdk.InstrumentCriteria\x12\x11\n\taggregate\x18\x02 \x01(\tB\xa2\x01\n(com.kaiko.sdk.stream.aggregates_ohlcv_v1P\x01ZPgithub.com/kaikodata/kaiko-go-sdk/stream/aggregates_ohlcv_v1;aggregates_ohlcv_v1\xaa\x02!KaikoSdk.Stream.AggregatesOHLCVV1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sdk.stream.aggregates_ohlcv_v1.request_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n(com.kaiko.sdk.stream.aggregates_ohlcv_v1P\001ZPgithub.com/kaikodata/kaiko-go-sdk/stream/aggregates_ohlcv_v1;aggregates_ohlcv_v1\252\002!KaikoSdk.Stream.AggregatesOHLCVV1'
  _globals['_STREAMAGGREGATESOHLCVREQUESTV1']._serialized_start=94
  _globals['_STREAMAGGREGATESOHLCVREQUESTV1']._serialized_end=204
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sdk/core/instrument_criteria.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"sdk/core/instrument_criteria.proto\x12\x08kaikosdk\"N\n\x12InstrumentCriteria\x12\x10\n\x08\x65xchange\x18\x01 \x01(\t\x12\x18\n\x10instrument_class\x18\x02 \x01(\t\x12\x0c\n\x04\x63ode\x18\x03 \x01(\tBS\n\x12\x63om.kaiko.sdk.coreP\x01Z+github.com/kaikodata/kaiko-go-sdk/core;core\xaa\x02\rKaikoSdk.Coreb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sdk.core.instrument_criteria_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\022com.kaiko.sdk.coreP\001Z+github.com/kaikodata/kaiko-go-sdk/core;core\252\002\rKaikoSdk.Core'
  _globals['_INSTRUMENTCRITERIA']._serialized_start=48
  _globals['_INSTRUMENTCRITERIA']._serialized_end=126
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sdk/stream/index_forex_rate_v1/response.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from kaikosdk.core import data_interval_pb2 as sdk_dot_core_dot_data__interval__pb2
from kaikosdk.stream.index_v1 import commodity_pb2 as sdk_dot_stream_dot_index__v1_dot_commodity__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-sdk/stream/index_forex_rate_v1/response.proto\x12\x08kaikosdk\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1csdk/core/data_interval.proto\x1a#sdk/stream/index_v1/commodity.proto\"T\n\x16StreamForexIndexPublic\x12\x0c\n\x04name\x18\x01 \x01(\t\x12,\n\x08ts_event\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"c\n\x16StreamForexIndexDetail\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05price\x18\x02 \x01(\x01\x12,\n\x08ts_event\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\x8f\x01\n%StreamForexIndexServiceResponseDetail\x12\x34\n\nunderlying\x18\x01 \x01(\x0b\x32 .kaikosdk.StreamForexIndexDetail\x12\x30\n\x06\x66xrate\x18\x02 \x01(\x0b\x32 .kaikosdk.StreamForexIndexDetail\"\x8f\x01\n%StreamForexIndexServiceResponsePublic\x12\x34\n\nunderlying\x18\x01 \x01(\x0b\x32 .kaikosdk.StreamForexIndexPublic\x12\x30\n\x06\x66xrate\x18\x02 \x01(\x0b\x32 .kaikosdk.StreamForexIndexPublic\"\xdc\x02\n%StreamIndexForexRateServiceResponseV1\x12\x12\n\nindex_code\x18\x01 \x01(\t\x12\x31\n\tcommodity\x18\x02 \x01(\x0e\x32\x1e.kaikosdk.StreamIndexCommodity\x12(\n\x08interval\x18\x03 \x01(\x0b\x32\x16.kaikosdk.DataInterval\x12\x44\n\x0b\x63omposition\x18\x04 \x01(\x0b\x32/.kaikosdk.StreamForexIndexServiceResponsePublic\x12\r\n\x05price\x18\x05 \x01(\x01\x12,\n\x08ts_event\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12?\n\x06\x64\x65tail\x18\x07 \x01(\x0b\x32/.kaikosdk.StreamForexIndexServiceResponseDetailB\xa1\x01\n(com.kaiko.sdk.stream.index_forex_rate_v1P\x01ZPgithub.com/kaikodata/kaiko-go-sdk/stream/index_forex_rate_v1;index_forex_rate_v1\xaa\x02 KaikoSdk.Stream.IndexForexRateV1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sdk.stream.index_forex_rate_v1.response_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n(com.kaiko.sdk.stream.index_forex_rate_v1P\001ZPgithub.com/kaikodata/kaiko-go-sdk/stream/index_forex_rate_v1;index_forex_rate_v1\252\002 KaikoSdk.Stream.IndexForexRateV1'
  _globals['_STREAMFOREXINDEXPUBLIC']._serialized_start=159
  _globals['_STREAMFOREXINDEXPUBLIC']._serialized_end=243
  _globals['_STREAMFOREXINDEXDETAIL']._serialized_start=245
  _globals['_STREAMFOREXINDEXDETAIL']._serialized_end=344
  _globals['_STREAMFOREXINDEXSERVICERESPONSEDETAIL']._serialized_start=347
  _globals['_STREAMFOREXINDEXSERVICERESPONSEDETAIL']._serialized_end=490
  _globals['_STREAMFOREXINDEXSERVICERESPONSEPUBLIC']._serialized_start=493
  _globals['_STREAMFOREXINDEXSERVICERESPONSEPUBLIC']._serialized_end=636
  _globals['_STREAMINDEXFOREXRATESERVICERESPONSEV1']._serialized_start=639
  _globals['_STREAMINDEXFOREXRATESERVICERESPONSEV1']._serialized_end=987
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sdk/stream/market_update_v1/request.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from kaikosdk.core import data_interval_pb2 as sdk_dot_core_dot_data__interval__pb2
from kaikosdk.core import instrument_criteria_pb2 as sdk_dot_core_dot_instrument__criteria__pb2
from kaikosdk.stream.market_update_v1 import commodity_pb2 as sdk_dot_stream_dot_market__update__v1_dot_commodity__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)sdk/stream/market_update_v1/request.proto\x12\x08kaikosdk\x1a\x1csdk/core/data_interval.proto\x1a\"sdk/core/instrument_criteria.proto\x1a+sdk/stream/market_update_v1/commodity.proto\"\xd7\x02\n\x1bStreamMarketUpdateRequestV1\x12\x39\n\x13instrument_criteria\x18\x01 \x01(\x0b\x32\x1c.kaikosdk.InstrumentCriteria\x12:\n\x0b\x63ommodities\x18\x02 \x03(\x0e\x32%.kaikosdk.StreamMarketUpdateCommodity\x12(\n\x08interval\x18\x03 \x01(\x0b\x32\x16.kaikosdk.DataInterval\x12V\n\rsnapshot_type\x18\x04 \x01(\x0e\x32;.kaikosdk.StreamMarketUpdateRequestV1.OrderbookSnapshotTypeB\x02\x18\x01\"?\n\x15OrderbookSnapshotType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0f\n\x0bTEN_PERCENT\x10\x01\x12\x08\n\x04\x46ULL\x10\x02\x42\x96\x01\n%com.kaiko.sdk.stream.market_update_v1P\x01ZJgithub.com/kaikodata/kaiko-go-sdk/stream/market_update_v1;market_update_v1\xaa\x02\x1eKaikoSdk.Stream.MarketUpdateV1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sdk.stream.market_update_v1.request_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%com.kaiko.sdk.stream.market_update_v1P\001ZJgithub.com/kaikodata/kaiko-go-sdk/stream/market_update_v1;market_update_v1\252\002\036KaikoSdk.Stream.MarketUpdateV1'
  _STREAMMARKETUPDATEREQUESTV1.fields_by_name['snapshot_type']._options = None
  _STREAMMARKETUPDATEREQUESTV1.fields_by_name['snapshot_type']._serialized_options = b'\030\001'
  _globals['_STREAMMARKETUPDATEREQUESTV1']._serialized_start=167
  _globals['_STREAMMARKETUPDATEREQUESTV1']._serialized_end=510
  _globals['_STREAMMARKETUPDATEREQUESTV1_ORDERBOOKSNAPSHOTTYPE']._serialized_start=447
  _globals['_STREAMMARKETUPDATEREQUESTV1_ORDERBOOKSNAPSHOTTYPE']._serialized_end=510
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sdk/stream/aggregated_quote_v2/request.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from kaikosdk.core import data_interval_pb2 as sdk_dot_core_dot_data__interval__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,sdk/stream/aggregated_quote_v2/request.proto\x12\x08kaikosdk\x1a\x1csdk/core/data_interval.proto\"\x92\x01\n\x1eStreamAggregatedQuoteRequestV2\x12\x18\n\x10instrument_class\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12(\n\x08interval\x18\x03 \x01(\x0b\x32\x16.kaikosdk.DataInterval\x12\x1e\n\x16include_unvetted_price\x18\x04 \x01(\x08\x42\xa2\x01\n(com.kaiko.sdk.stream.aggregated_quote_v2P\x01ZPgithub.com/kaikodata/kaiko-go-sdk/stream/aggregated_quote_v2;aggregated_quote_v2\xaa\x02!KaikoSdk.Stream.AggregatedQuoteV2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sdk.stream.aggregated_quote_v2.request_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n(com.kaiko.sdk.stream.aggregated_quote_v2P\001ZPgithub.com/kaikodata/kaiko-go-sdk/stream/aggregated_quote_v2;aggregated_quote_v2\252\002!KaikoSdk.Stream.AggregatedQuoteV2'
  _globals['_STREAMAGGREGATEDQUOTEREQUESTV2']._serialized_start=89
  _globals['_STREAMAGGREGATEDQUOTEREQUESTV2']._serialized_end=235
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sdk/stream/index_multi_assets_v1/response.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from kaikosdk.core import data_interval_pb2 as sdk_dot_core_dot_data__interval__pb2
from kaikosdk.stream.index_v1 import commodity_pb2 as sdk_dot_stream_dot_index__v1_dot_commodity__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/sdk/stream/index_multi_assets_v1/response.proto\x12\x08kaikosdk\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1csdk/core/data_interval.proto\x1a#sdk/stream/index_v1/commodity.proto\"\x81\x02\n0StreamIndexMultiAssetsServiceResponseComposition\x12\x1d\n\x15underlying_instrument\x18\x01 \x01(\t\x12\x0c\n\x04\x62\x61se\x18\x02 \x01(\t\x12\r\n\x05quote\x18\x03 \x01(\t\x12\x11\n\texchanges\x18\x04 \x03(\t\x12\x33\n\x13instrument_interval\x18\x05 \x01(\x0b\x32\x16.kaikosdk.DataInterval\x12\x1b\n\x13\x63urrency_conversion\x18\x06 \x01(\t\x12,\n\x08ts_event\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xd8\x01\n)StreamIndexMultiAssetsServiceResponsePair\x12\x1d\n\x15underlying_instrument\x18\x01 \x01(\t\x12\x36\n\x10underlying_price\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12\x18\n\x10weighting_factor\x18\x03 \x01(\x01\x12\x16\n\x0e\x63\x61pping_factor\x18\x04 \x01(\x01\x12\"\n\x1a\x63urrency_conversion_factor\x18\x05 \x01(\x01\"\x97\x01\n+StreamIndexMultiAssetsServiceResponsePrices\x12\x13\n\x0bindex_value\x18\x01 \x01(\x01\x12\x0f\n\x07\x64ivisor\x18\x02 \x01(\x01\x12\x42\n\x05pairs\x18\x03 \x03(\x0b\x32\x33.kaikosdk.StreamIndexMultiAssetsServiceResponsePair\"\xa4\x03\n\'StreamIndexMultiAssetsServiceResponseV1\x12\x31\n\tcommodity\x18\x01 \x01(\x0e\x32\x1e.kaikosdk.StreamIndexCommodity\x12\x12\n\nindex_code\x18\x02 \x01(\t\x12(\n\x08interval\x18\x03 \x01(\x0b\x32\x16.kaikosdk.DataInterval\x12\x12\n\nmain_quote\x18\x04 \x01(\t\x12P\n\x0c\x63ompositions\x18\x05 \x03(\x0b\x32:.kaikosdk.StreamIndexMultiAssetsServiceResponseComposition\x12\x44\n\x05price\x18\x06 \x01(\x0b\x32\x35.kaikosdk.StreamIndexMultiAssetsServiceResponsePrices\x12,\n\x08ts_event\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nts_compute\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\xa9\x01\n*com.kaiko.sdk.stream.index_multi_assets_v1P\x01ZTgithub.com/kaikodata/kaiko-go-sdk/stream/index_multi_assets_v1;index_multi_assets_v1\xaa\x02\"KaikoSdk.Stream.IndexMultiAssetsV1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sdk.stream.index_multi_assets_v1.response_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n*com.kaiko.sdk.stream.index_multi_assets_v1P\001ZTgithub.com/kaikodata/kaiko-go-sdk/stream/index_multi_assets_v1;index_multi_assets_v1\252\002\"KaikoSdk.Stream.IndexMultiAssetsV1'
  _globals['_STREAMINDEXMULTIASSETSSERVICERESPONSECOMPOSITION']._serialized_start=194
  _globals['_STREAMINDEXMULTIASSETSSERVICERESPONSECOMPOSITION']._serialized_end=451
  _globals['_STREAMINDEXMULTIASSETSSERVICERESPONSEPAIR']._serialized_start=454
  _globals['_STREAMINDEXMULTIASSETSSERVICERESPONSEPAIR']._serialized_end=670
  _globals['_STREAMINDEXMULTIASSETSSERVICERESPONSEPRICES']._serialized_start=673
  _globals['_STREAMINDEXMULTIASSETSSERVICERESPONSEPRICES']._serialized_end=824
  _globals['_STREAMINDEXMULTIASSETSSERVICERESPONSEV1']._serialized_start=827
  _globals['_STREAMINDEXMULTIASSETSSERVICERESPONSEV1']._serialized_end=1247
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sdk/stream/trades_v1/response.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from kaikosdk.core import wrappers_pb2 as sdk_dot_core_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#sdk/stream/trades_v1/response.proto\x12\x08kaikosdk\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x17sdk/core/wrappers.proto\"\x94\x04\n\x16StreamTradesResponseV1\x12Y\n\x15\x61\x64\x64itional_properties\x18\x01 \x03(\x0b\x32:.kaikosdk.StreamTradesResponseV1.AdditionalPropertiesEntry\x12\x0e\n\x06\x61mount\x18\x02 \x01(\x01\x12\r\n\x05\x63lass\x18\x03 \x01(\t\x12\x0c\n\x04\x63ode\x18\x04 \x01(\t\x12\x10\n\x08\x65xchange\x18\x05 \x01(\t\x12\x13\n\x0bsequence_id\x18\x06 \x01(\t\x12\n\n\x02id\x18\x07 \x01(\t\x12\r\n\x05price\x18\x08 \x01(\x01\x12\x38\n\x04side\x18\t \x01(\x0e\x32*.kaikosdk.StreamTradesResponseV1.TradeSide\x12-\n\x0bts_exchange\x18\n \x01(\x0b\x32\x18.kaikosdk.TimestampValue\x12/\n\rts_collection\x18\x0b \x01(\x0b\x32\x18.kaikosdk.TimestampValue\x12,\n\x08ts_event\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x1a;\n\x19\x41\x64\x64itionalPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"+\n\tTradeSide\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x07\n\x03\x42UY\x10\x01\x12\x08\n\x04SELL\x10\x02\x42{\n\x1e\x63om.kaiko.sdk.stream.trades_v1P\x01Z<github.com/kaikodata/kaiko-go-sdk/stream/trades_v1;trades_v1\xaa\x02\x18KaikoSdk.Stream.TradesV1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sdk.stream.trades_v1.response_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\036com.kaiko.sdk.stream.trades_v1P\001Z<github.com/kaikodata/kaiko-go-sdk/stream/trades_v1;trades_v1\252\002\030KaikoSdk.Stream.TradesV1'
  _STREAMTRADESRESPONSEV1_ADDITIONALPROPERTIESENTRY._options = None
  _STREAMTRADESRESPONSEV1_ADDITIONALPROPERTIESENTRY._serialized_options = b'8\001'
  _globals['_STREAMTRADESRESPONSEV1']._serialized_start=108
  _globals['_STREAMTRADESRESPONSEV1']._serialized_end=640
  _globals['_STREAMTRADESRESPONSEV1_ADDITIONALPROPERTIESENTRY']._serialized_start=536
  _globals['_STREAMTRADESRESPONSEV1_ADDITIONALPROPERTIESENTRY']._serialized_end=595
  _globals['_STREAMTRADESRESPONSEV1_TRADESIDE']._serialized_start=597
  _globals['_STREAMTRADESRESPONSEV1_TRADESIDE']._serialized_end=640
# @@protoc_insertion_point(module_scope)



from setuptools import setup, find_packages

setup(name='kaikosdk',
      version='1.14.1',
      description='Kaiko SDK',
      url='https://www.kaiko.com/',
      author='Kaiko',
      author_email='hello@kaiko.com',
      license='MIT',
      packages=find_packages(),
      zip_safe=False)


# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sdk/stream/market_update_v1/commodity.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+sdk/stream/market_update_v1/commodity.proto\x12\x08kaikosdk*o\n\x1bStreamMarketUpdateCommodity\x12\x10\n\x0cSMUC_UNKNOWN\x10\x00\x12\x0e\n\nSMUC_TRADE\x10\x01\x12\x14\n\x10SMUC_TOP_OF_BOOK\x10\x02\x12\x18\n\x14SMUC_FULL_ORDER_BOOK\x10\x03\x42\x96\x01\n%com.kaiko.sdk.stream.market_update_v1P\x01ZJgithub.com/kaikodata/kaiko-go-sdk/stream/market_update_v1;market_update_v1\xaa\x02\x1eKaikoSdk.Stream.MarketUpdateV1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sdk.stream.market_update_v1.commodity_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%com.kaiko.sdk.stream.market_update_v1P\001ZJgithub.com/kaikodata/kaiko-go-sdk/stream/market_update_v1;market_update_v1\252\002\036KaikoSdk.Stream.MarketUpdateV1'
  _globals['_STREAMMARKETUPDATECOMMODITY']._serialized_start=57
  _globals['_STREAMMARKETUPDATECOMMODITY']._serialized_end=168
# @@protoc_insertion_point(module_scope)
